@@ -2,7 +2,6 @@
 Person settings
 """
 from dataclasses import dataclass
-from enum import Enum
 from typing import Optional
 
 from pydantic import Field
@@ -29,6 +28,7 @@ from .receptionist import ReceptionistApi
 from .voicemail import VoicemailApi
 from ..api_child import ApiChild
 from ..base import ApiModel
+from ..base import SafeEnum as Enum
 from ..common import UserType, PrimaryOrShared
 from ..common.schedules import ScheduleApi, ScheduleApiBase
 from ..rest import RestSession
@@ -76,7 +76,6 @@ class TelephonyDevice(ApiModel):
     owner: DeviceOwner
     #: Activation state of device.
     activation_state: DeviceActivationState
-    pre_onboarding_device_id: str
 
 
 class PersonDevicesResponse(ApiModel):
