@@ -1,11 +1,11 @@
 """
 Person PTT settings API
 """
-from enum import Enum
 from typing import Optional, Union
 
 from .common import PersonSettingsApiChild
 from ..base import ApiModel
+from ..base import SafeEnum as Enum
 
 __all__ = ['PTTConnectionType', 'PushToTalkAccessType', 'PushToTalkSettings', 'PushToTalkApi']
 
